@@ -1,10 +1,9 @@
 package Net::Rovio;
-use Data::Dumper;
 use strict;
 use warnings;
 use LWP::Simple;
 use vars qw($VERSION);
-$VERSION = "1.2";
+$VERSION = "1.4";
 my $answer ="";
 
 sub new {
@@ -1261,13 +1260,9 @@ Returns the camera sensor setting:
 
 =over 4
 
-=begin text
-
-50 - 50Hz
-60 - 60Hz
-0 - Auto detect
-
-=end text
+=item 50 - 50Hz
+=item 60 - 60Hz
+=item 0 - Auto detect
 
 =back
 
@@ -1283,8 +1278,6 @@ GetDDNS Returns:
 
 =over 4
 
-=begin text
-
 'User' => '',
 'Pass' => '',
 'Service' => '',
@@ -1299,14 +1292,12 @@ GetDDNS Returns:
 
 Info above can return:
 
-Updated
-Updating
-Failed
-Updating IP
-Checked
-Not Update
-
-=end text
+=item Updated
+=item Updating
+=item Failed
+=item Updating IP
+=item Checked
+=item Not Update
 
 =back
 
@@ -1318,13 +1309,9 @@ GetHTTP Returns:
 
 =over 4
 
-=begin text
-
 'Port1' => '',
 'Port0' => '80'
 
-=end text
-
 =back
 
 Note that the Port0 setting should only be changed if you know what you are doing.
@@ -1338,8 +1325,6 @@ GetIP Returns:
 
 =over 4
 
-=begin text
-
 'CurrentDNS0' => '4.2.2.3',
 'DNS2' => '0.0.0.0',
 'IPWay' => 'manually',
@@ -1357,8 +1342,6 @@ GetIP Returns:
 'IP' => '192.168.1.200',
 'CurrentIPState' => 'STATIC_IP_OK'
 
-=end text
-
 =back
 
 =head2 $rovio->getlog()
@@ -1369,23 +1352,17 @@ GetLog Returns:
 
 =over 4
 
-=begin text
-
 'Time' => '0000001029',
 'LogLines' => [
                '27    C0A8017D18F09FE518F00000000007'
               ]
 
-=end text
-
 =back
 
 The Time represents time since power on in seconds. LogLines are individual log events.
 
 Log Lines -
 
-=begin text
-
 byte 0, 1 - reason for recording this log, refer to table below. eg: 27 is shown that new client connect to the IP Camera.
 byte 2 ~ 5 - reserved.
 byte 6 ~ 13 - operator's IP. eg: 0A820B57 is 10.130.11.87.
@@ -1418,8 +1395,6 @@ For byte 0, 1 - Log reason
 31 Set Server IP
 32 Set Http Port
 
-=end text
-
 =head2 $rovio->getlogo()
 
 Gets the 2 possible strings of text currently overlayed on the image, and thier position.
@@ -1428,15 +1403,11 @@ GetLogo Returns:
 
 =over 4
 
-=begin text
-
 'ShowString' => '',
 'ShowPos' => '0',
 'ShowString2' => '',
 'ShowPos2' => '0'
 
-=end text
-
 =back
 
 =head2 $rovio->getmail()
@@ -1447,8 +1418,6 @@ GetMail Returns:
 
 =over 4
 
-=begin text
-
 'Subject' => 'Rovio Snapshot',
 'User' => '',
 'MailServer' => '',
@@ -1460,8 +1429,6 @@ GetMail Returns:
 'PassWord' => '',
 'Body' => 'Check out this photo from my Rovio.'
 
-=end text
-
 =back
 
 =head2 $rovio->getmcureport()
@@ -1472,8 +1439,6 @@ GetMCUReport Currently Returns:
 
 =over 4
 
-=begin text
-
           'rear_encoder_ticks' => '00',
           'packet_length' => 14,
           'right_encoder_ticks' => '00',
@@ -1484,8 +1449,6 @@ GetMCUReport Currently Returns:
           'rear_wheel_dir' => '0',
           'left_wheel_dir' => '1'
 
-=end text
-
 =back
 
 =head2 $rovio->getmediaformat()
@@ -1496,31 +1459,23 @@ GetMediaFormat Returns:
 
 =over 4
 
-=begin text
-
           'Video' => '1',
           'Audio' => '4'
 
-=end text
-
 =back
 
 The possible return values are:
 
-=begin text
-
 For Audio:
- 0 - AMR
- 1 - PCM
- 2 - IMAADPCM
- 3 - ULAW
- 4 - ALAW
+=item 0 - AMR
+=item 1 - PCM
+=item 2 - IMAADPCM
+=item 3 - ULAW
+=item 4 - ALAW
 
 For Video:
- 1 - H263
- 2 - MPEG4
-
-=end text
+=item 1 - H263
+=item 2 - MPEG4
 
 The same values can be used with the setmediaformat() command.
 Note that some Video settings will not work with the built-in Rovio webpage
@@ -1542,8 +1497,6 @@ GetReport Returns:
 
 =over 4
 
-=begin text
-
           'wifi_ss' => '200',
           'show_time' => '0',
           'theta' => '1.098',
@@ -1578,8 +1531,6 @@ responses = 0',
           'resistance' => '0',
           'ddns_state' => '0'
 
-=end text
-
 =back
 
 =head2 $rovio->getstatus()
@@ -1590,8 +1541,6 @@ GetStatus Returns:
 
 =over 4
 
-=begin text
-
           'ftp_state' => '0',
           'saturation' => '000',
           'camera_state' => '01',
@@ -1627,8 +1576,6 @@ GetStatus Returns:
           'image_file_length' => '00000000',
           'sharpness' => '000'
 
-=end text
-
 =back
 
 =head2 $rovio->gettime()
@@ -1639,15 +1586,11 @@ GetTime Returns:
 
 =over 4
 
-=begin text
-
           'TimeZone' => '240',
           'NtpServer' => '',
           'UseNtp' => '0',
           'Sec1970' => '99663'
 
-=end text
-
 =back
 
 =head2 $rovio->gettuningparameters()
@@ -1658,8 +1601,6 @@ GetTuningParameters Returns:
 
 =over 4
 
-=begin text
-
           'ManTurn' => '8',
           'ManDrive' => '7',
           'DockTimeout' => '72',
@@ -1671,8 +1612,6 @@ responses = 0',
           'DriveTurn' => '6',
           'HomingTurn' => '8'
 
-=end text
-
 =back
 
 =head2 $rovio->getver()
@@ -1683,12 +1622,8 @@ GetVer Returns:
 
 =over 4
 
-=begin text
-
  Ver: Jan 12 2010 14:41:24 $Revision: 5.3503$
 
-=end text
-
 =back
 
 =head2 $rovio->getwlan()
@@ -1699,8 +1634,6 @@ GetWlan Returns:
 
 =over 4
 
-=begin text
-
           'Wep128type' => 'Wep128HEX',
           'Wep64type' => 'Wep64HEX',
           'Channel' => '5',
@@ -1712,8 +1645,6 @@ GetWlan Returns:
           'WepGroup' => '0',
           'WepAsc' => ''
 
-=end text
-
 =back
 
 =head2 $rovio->halt()
@@ -1728,13 +1659,9 @@ Sample:
 
 =over 4
 
-=begin text
-
 $rovio->light('on');
 $rovio->light('off');
 
-=begin text
-
 =back
 
 =head2 $rovio->manualdrive(<drive value>,<speed value>)
@@ -1745,16 +1672,10 @@ Sample:
 
 =over 4
 
-=begin text
-
 $rovio->manualdrive("1","2");
 
-=end text
-
 =back
 
-=begin text
-
 Drive Values:
 0 (Stop)
 1 (Forward)
@@ -1779,8 +1700,6 @@ Drive Values:
 Speed Values:
 1 (fastest) - 10 (slowest)
 
-=end text
-
 =head2 $rovio->pauseplaying()
 
 Pause the currently playing path.
@@ -1833,16 +1752,12 @@ Sample:
 
 =over 4
 
-=begin text
-
 @params = {   "Forward" => 8,
             "DriveTurn" => 6,
            "HomingTurn" => 8
            };
 $rovio->settuningparameters(@params);
 
-=end text
-
 =back
 
 =head2 $rovio->startrecording()
@@ -1857,15 +1772,11 @@ State Returns:
 
 =over 4
 
-=begin text
-
-idle
-driving home
-docking
-executing path
-recording path
-
-=end text
+=item idle
+=item driving home
+=item docking
+=item executing path
+=item recording path
 
 =back
 
@@ -1881,7 +1792,6 @@ Stops recording the current path, and saves it in the Rovio with the name given.
 
 Updates the saved home position within the Rovio to the current location of the Rovio.
 
-
 =back
 
 =head1 DEPENDENCIES
